@@ -116,7 +116,7 @@ class ProjectManager(QObject):
 
     def load_decodings(self):
         if self.project_file:
-            prefix = os.path.realpath(os.path.dirname(self.project_file))
+            return
         else:
             prefix = os.path.realpath(os.path.join(constants.SETTINGS.fileName(), ".."))
 
@@ -143,25 +143,15 @@ class ProjectManager(QObject):
             self.decodings = fallback
             return
 
-        if not f:
-            self.decodings = fallback
-            return
-
         decodings = []
-        for line in f:
+        for line in map(str.strip, f):
             tmp_conf = []
-            for j in line.split(","):
-                tmp = j.strip()
-                tmp = tmp.replace("'", "")
-                if not "\n" in tmp and tmp != "":
-                    tmp_conf.append(tmp)
+            for j in map(str.strip, line.split(",")):
+                tmp_conf.append(j.replace("'", ""))
             decodings.append(Encoding(tmp_conf))
         f.close()
 
-        if decodings:
-            self.decodings = decodings
-        else:
-            self.decodings = fallback
+        self.decodings = decodings if decodings else fallback
 
     @staticmethod
     def read_device_conf_dict(tag: ET.Element, target_dict):
@@ -170,7 +160,10 @@ class ProjectManager(QObject):
 
         for dev_tag in tag:
             try:
-                value = float(dev_tag.text)
+                try:
+                    value = int(dev_tag.text)
+                except ValueError:
+                    value = float(dev_tag.text)
             except ValueError:
                 value = dev_tag.text
             target_dict[dev_tag.tag] = value
@@ -212,7 +205,7 @@ class ProjectManager(QObject):
     def set_project_folder(self, path, ask_for_new_project=True, close_all=True):
         if self.project_file is not None or close_all:
             # Close existing project (if any) or existing files if requested
-            self.main_controller.close_all()
+            self.main_controller.close_all_files()
         FileOperator.RECENT_PATH = path
         util.PROJECT_PATH = path
         self.project_path = path
@@ -248,8 +241,8 @@ class ProjectManager(QObject):
             self.read_compare_frame_groups(root)
             self.decodings = Encoding.read_decoders_from_xml_tag(root.find("protocol"))
 
-            cfc.proto_analyzer.message_types = self.read_message_types()
-            cfc.fill_message_type_combobox()
+            cfc.proto_analyzer.message_types[:] = self.read_message_types()
+            cfc.message_type_table_model.update()
             cfc.proto_analyzer.from_xml_tag(root=root.find("protocol"), participants=self.participants,
                                             decodings=cfc.decodings)
 
@@ -304,21 +297,26 @@ class ProjectManager(QObject):
         for signal_tag in root.iter("signal"):
             existing_filenames[signal_tag.attrib["filename"]] = signal_tag
 
-        if os.path.relpath(signal.filename, self.project_path) in existing_filenames.keys():
-            signal_tag = existing_filenames[os.path.relpath(signal.filename, self.project_path)]
+        try:
+            file_path = os.path.relpath(signal.filename, self.project_path)
+        except ValueError:
+            # Can happen e.g. on Windows when Project is in C:\ and signal on D:\
+            file_path = signal.filename
+
+        if file_path in existing_filenames.keys():
+            signal_tag = existing_filenames[file_path]
         else:
             # Create new tag
             signal_tag = ET.SubElement(root, "signal")
 
         signal_tag.set("name", signal.name)
-        signal_tag.set("filename", os.path.relpath(signal.filename, self.project_path))
+        signal_tag.set("filename", file_path)
         signal_tag.set("bit_length", str(signal.bit_len))
         signal_tag.set("qad_center", str(signal.qad_center))
         signal_tag.set("tolerance", str(signal.tolerance))
         signal_tag.set("noise_threshold", str(signal.noise_threshold))
         signal_tag.set("noise_minimum", str(signal.noise_min_plot))
         signal_tag.set("noise_maximum", str(signal.noise_max_plot))
-        signal_tag.set("auto_detect_on_modulation_changed", str(signal.auto_detect_on_modulation_changed))
         signal_tag.set("modulation_type", str(signal.modulation_type))
         signal_tag.set("sample_rate", str(signal.sample_rate))
         signal_tag.set("pause_threshold", str(signal.pause_threshold))
@@ -402,7 +400,12 @@ class ProjectManager(QObject):
                 open_files.append(open_filename)
 
                 file_tag = ET.SubElement(root, "open_file")
-                file_tag.set("name", os.path.relpath(open_filename, self.project_path))
+                try:
+                    file_path = os.path.relpath(open_filename, self.project_path)
+                except ValueError:
+                    file_path = open_filename
+
+                file_tag.set("name", file_path)
                 file_tag.set("position", str(i))
             except Exception:
                 pass
@@ -420,7 +423,12 @@ class ProjectManager(QObject):
             for proto_frame in cfc.protocols[i]:
                 if proto_frame.filename:
                     proto_tag = ET.SubElement(group_tag, "cf_protocol")
-                    proto_tag.set("filename", os.path.relpath(proto_frame.filename, self.project_path))
+                    try:
+                        rel_file_name = os.path.relpath(proto_frame.filename, self.project_path)
+                    except ValueError:
+                        rel_file_name = proto_frame.filename
+
+                    proto_tag.set("filename", rel_file_name)
 
         root.append(cfc.proto_analyzer.to_xml_tag(decodings=cfc.decodings, participants=self.participants,
                                                   messages=[msg for proto in cfc.full_protocol_list for msg in
@@ -438,8 +446,13 @@ class ProjectManager(QObject):
         tree = ET.parse(self.project_file)
         root = tree.getroot()
 
+        try:
+            signal_filename = os.path.relpath(signal.filename, self.project_path)
+        except ValueError:
+            signal_filename = signal.filename
+
         for sig_tag in root.iter("signal"):
-            if sig_tag.attrib["filename"] == os.path.relpath(signal.filename, self.project_path):
+            if sig_tag.attrib["filename"] == signal_filename:
                 messages_tag = sig_tag.find("messages")
 
                 try:
@@ -459,20 +472,26 @@ class ProjectManager(QObject):
 
         tree = ET.parse(self.project_file)
         root = tree.getroot()
+
+        try:
+            signal_filename = os.path.relpath(signal.filename, self.project_path)
+        except ValueError:
+            signal_filename = signal.filename
+
         for sig_tag in root.iter("signal"):
-            if sig_tag.attrib["filename"] == os.path.relpath(signal.filename,
-                                                             self.project_path):
+            if sig_tag.attrib["filename"] == signal_filename:
                 signal.name = sig_tag.attrib["name"]
                 signal.qad_center = float(sig_tag.get("qad_center", 0))
                 signal.tolerance = int(sig_tag.get("tolerance", 5))
-                signal.auto_detect_on_modulation_changed = False if \
-                    sig_tag.attrib[
-                        "auto_detect_on_modulation_changed"] == 'False' else True
 
                 signal.noise_threshold = float(sig_tag.get("noise_threshold", 0.1))
                 signal.sample_rate = float(sig_tag.get("sample_rate", 1e6))
                 signal.bit_len = int(sig_tag.get("bit_length", 100))
-                signal.modulation_type = int(sig_tag.get("modulation_type", 0))
+                try:
+                    # Legacy support when modulation type was integer
+                    signal.modulation_type = Signal.MODULATION_TYPES[int(sig_tag.get("modulation_type", 0))]
+                except (ValueError, IndexError):
+                    signal.modulation_type = sig_tag.get("modulation_type", "ASK")
                 signal.pause_threshold = int(sig_tag.get("pause_threshold", 8))
                 signal.message_length_divisor = int(sig_tag.get("message_length_divisor", 1))
                 break
@@ -487,7 +506,9 @@ class ProjectManager(QObject):
 
             for file_tag in root.findall("open_file"):
                 pos = int(file_tag.attrib["position"])
-                filename = os.path.normpath(os.path.join(self.project_path, file_tag.attrib["name"]))
+                filename = file_tag.attrib["name"]
+                if not os.path.isfile(filename):
+                    filename = os.path.normpath(os.path.join(self.project_path, filename))
                 file_names.insert(pos, filename)
 
             QApplication.setOverrideCursor(Qt.WaitCursor)
@@ -514,7 +535,9 @@ class ProjectManager(QObject):
             group = tree_root.child(int(id))
 
             for proto_tag in group_tag.iter("cf_protocol"):
-                filename = os.path.normpath(os.path.join(self.project_path, proto_tag.attrib["filename"]))
+                filename = proto_tag.attrib["filename"]
+                if not os.path.isfile(filename):
+                    filename = os.path.normpath(os.path.join(self.project_path, filename))
                 try:
                     proto_frame_item = next((p for p in proto_frame_items if p.protocol.filename == filename))
                 except StopIteration:
